@@ -1,4 +1,4 @@
-/* $Id: cmd.h,v 1.3 2001/05/12 18:44:37 mhe Exp $
+/* $Id: cmd.h,v 1.5 2004/05/20 11:10:52 mhe Exp $
  *
  * cmd.h -- read and execute commands, this is the main loop
  *
@@ -25,7 +25,6 @@ typedef struct {
 	bool needconnect, needlogdin;
 	bool auto_unquote;
 	int cpltype;
-	char *hint;
 	vfunc func;
 } cmd_t;
 
@@ -36,6 +35,7 @@ int rearrange_redirections(args_t *args);
 
 void command_loop(void);
 void exit_yafc(void);
+extern void exe_cmdline(char *str, bool aliases_are_expanded);
 
 extern cmd_t cmds[];
 
