@@ -1,4 +1,4 @@
-/* $Id: rdirectory.h,v 1.3 2001/05/12 18:44:04 mhe Exp $
+/* $Id: rdirectory.h,v 1.5 2002/12/02 12:27:55 mhe Exp $
  *
  * rdirectory.h -- representation of a remote directory
  *
@@ -20,13 +20,14 @@
 
 typedef struct rdirectory
 {
-	char *path;  /* directory path */
+	char *path;        /* directory path */
 	list *files;       /* linked list of rfiles */
+	time_t timestamp;  /* time of creation */
 } rdirectory;
 
 rdirectory *rdir_create(void);
 void rdir_destroy(rdirectory *rdir);
-int rdir_parse(rdirectory *rdir, FILE *fp, const char *path);
+int rdir_parse(rdirectory *rdir, FILE *fp, const char *path, bool is_mlsd);
 rfile *rdir_get_file(rdirectory *rdir, const char *filename);
 unsigned long int rdir_size(rdirectory *rdir);
 
