@@ -1,4 +1,4 @@
-/* $Id: lglob.c,v 1.6 2002/12/02 12:39:41 mhe Exp $
+/* $Id: lglob.c,v 1.8 2004/05/20 11:10:52 mhe Exp $
  *
  * lglob.c -- local glob functions
  *
@@ -37,7 +37,7 @@
 list *lglob_create(void)
 {
 	list *gl;
-	gl = list_new((listfunc)xfree);
+	gl = list_new((listfunc)free);
 	return gl;
 }
 
@@ -74,7 +74,14 @@ int lglob_glob(list *gl, const char *mask, bool ignore_multiples,
 		return -1;
 	}
 
-	getcwd(tmp, PATH_MAX);
+	if (!getcwd(tmp, PATH_MAX)) {
+		if (ERANGE == errno) {
+			ftp_err("cwd too long\n");
+		} else {
+			ftp_err("getcwd(): %s\n", strerror(errno));
+		}
+		return -1;
+	}
 
 	while((de = readdir(dp)) != 0) {
 		char *path;
@@ -99,7 +106,7 @@ int lglob_glob(list *gl, const char *mask, bool ignore_multiples,
 			}
 			found = true;
 		}
-		xfree(path);
+		free(path);
 	}
 	closedir(dp);
 
