@@ -1,4 +1,4 @@
-/* $Id: transfer.c,v 1.9 2002/12/02 12:22:26 mhe Exp $
+/* $Id: transfer.c,v 1.12 2004/05/20 11:10:52 mhe Exp $
  *
  * transfer.c --
  *
@@ -70,7 +70,7 @@ static int max_printf(FILE *fp, int max, const char *fmt, ...)
 	} else
 		ret += fprintf(fp, "%s", e);
 
-	xfree(e);
+	free(e);
 	return ret;
 }
 
@@ -97,7 +97,7 @@ static int print_transfer_string(char *str,
 								 transfer_info *ti,
 								 float bps,
 								 unsigned int secs,
-								 unsigned int eta)
+								 unsigned long long int eta)
 {
 	int i;
 	int len = 0;
@@ -152,24 +152,24 @@ static int print_transfer_string(char *str,
 											gvLocalHomeDir));
 				break;
 			case 's':
-				len += max_printf(fp, minlen, "%sb", human_size(ti->size));
+				len += max_printf(fp, minlen, "%sB", human_size(ti->size));
 				break;
 			case 'S':
-				len += max_printf(fp, minlen, "%sb",
+				len += max_printf(fp, minlen, "%sB",
 								  (ti->total_size == -1L
 								   ? "??"
 								   : human_size(ti->total_size)));
 				break;
 			case 'b':
 				len += max_printf(fp, minlen < 2 ? minlen : minlen-2,
-								  "%sb/s", human_size(bps));
+								  "%sB/s", human_size(bps));
 				break;
 			case 'B':
 				if(ti->stalled >= 5)
 					len += max_printf(fp, minlen, "%s", _("stalled"));
 				else
 					len += max_printf(fp, minlen < 2 ? minlen : minlen-2,
-									  "%sb/s", human_size(bps));
+									  "%sB/s", human_size(bps));
 				break;
 			case 'e':
 				if(eta != (unsigned) -1)
@@ -316,7 +316,7 @@ int transfer_init_nohup(const char *str)
 	logfp = fopen(nohup_logfile, "w");
 	if(!logfp) {
 		perror(nohup_logfile);
-		xfree(nohup_logfile);
+		free(nohup_logfile);
 		logfp = 0;
 		return -1;
 	}
@@ -331,9 +331,9 @@ static RETSIGTYPE term_handler(int signum)
 {
 	time_t now = time(0);
 
-	fprintf(stderr, "%s [%sb of ", ftp->ti.remote_name,
+	fprintf(stderr, "%s [%sB of ", ftp->ti.remote_name,
 			human_size(ftp->ti.size));
-	fprintf(stderr, "%sb]\n", human_size(ftp->ti.total_size));
+	fprintf(stderr, "%sB]\n", human_size(ftp->ti.total_size));
 	printf(_("SIGTERM (terminate) received, exiting...\n"));
 	printf(_("Transfer aborted %s"), ctime(&now));
 	if(ftp->ti.remote_name)
@@ -391,7 +391,7 @@ void transfer_mail_msg(const char *fmt, ...)
 
 		asprintf(&e, "%s/yafcmail.tmp", gvWorkingDirectory);
 		tmpfilename = make_unique_filename(e);
-		xfree(e);
+		free(e);
 
 		mailfp = fopen(tmpfilename, "w+");
 		opened = true;
@@ -456,8 +456,8 @@ void transfer_end_nohup(void)
 
 	ftp_quit_all();
 	list_free(gvFtpList);
-	xfree(nohup_logfile);
-	xfree(nohup_command);
+	free(nohup_logfile);
+	free(nohup_command);
 	gvars_destroy();
 	exit(0);
 }
