@@ -1,21 +1,14 @@
-/* utils.c -- small (generic) functions
- * 
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
- * 
+/* $Id: utils.c,v 1.6 2004/05/20 11:10:52 mhe Exp $
+ *
+ * utils.c -- small (generic) functions
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -35,7 +28,7 @@ void listify_string(const char *str, list *lp)
 		if(list_search(lp, (listsearchfunc)strcmp, e) == 0)
 			list_additem(lp, xstrdup(e));
 	}
-	xfree(orgs);
+	free(orgs);
 }
 
 char *stringify_list(list *lp)
@@ -60,7 +53,10 @@ char *stringify_list(list *lp)
 
 char *make_unique_filename(const char *path)
 {
-	char *f = (char *)xmalloc(strlen(path)+10);
+	int maxistr = (sizeof(unsigned) * 8) / 3;
+
+	/* one for dot, one for NULL, and three just in case :P */
+	char *f = (char *)xmalloc(strlen(path) + maxistr + 5);
 	char *ext;
 	unsigned n = 0;
 
@@ -75,21 +71,20 @@ char *make_unique_filename(const char *path)
 	return f;
 }
 
-char *human_size(long size)
+char *human_size(long long int size)
 {
 	static char buf[17];
 
 	if(size < 1024)
-		sprintf(buf, "%lu", size);
-	/* else if(size < 1024*1024) */
-	else if(size < 999.5*1024)
-		sprintf(buf, "%.1fk", (double)size/1024);
-	else if(size < 999.5*1024*1024)
-		sprintf(buf, "%.2fM", (double)size/(1024*1024));
-	else
-		sprintf(buf, "%.2fG", (double)size/(1024*1024*1024));
-	/* they aren't transferring TB with ftp, eh? */
-	
+		sprintf(buf, "%llu", size);
+	else if(size < 999.5*1024) /* kilobinary */
+		sprintf(buf, "%.1fKi", (double)size/1024);
+	else if(size < 999.5*1024*1024) /* megabinary */
+		sprintf(buf, "%.2fMi", (double)size/(1024*1024));
+	else /* gigabinary */
+		sprintf(buf, "%.2fGi", (double)size/(1024*1024*1024));
+	/* they aren't transferring terabinaries with ftp, eh? */
+
 	return buf;
 }
 
@@ -117,7 +112,7 @@ void print_xterm_title(void)
 										 : gvXtermTitle2)
 									  : gvXtermTitle1);
 	print_xterm_title_string(xterm_title);
-	xfree(xterm_title);
+	free(xterm_title);
 }
 
 void reset_xterm_title(void)
@@ -126,7 +121,7 @@ void reset_xterm_title(void)
 
 	asprintf(&e, "\x1B]0;%s\x07", gvTerm);
 	print_xterm_title_string(e);
-	xfree(e);
+	free(e);
 }
 
 char* get_mode_string(mode_t m)
@@ -214,7 +209,8 @@ void invoke_shell(char *cmdline)
 		if(cmdline)
 			execl(shell, shell, "-c", cmdline, 0);
 		else {
-			printf(_("Executing '%s', use 'exit' to exit from shell...\n"), shell);
+			printf(_("Executing '%s', use 'exit' to exit from shell...\n"),
+				   shell);
 			execl(shell, shell, 0);
 		}
 		perror(shell);
